==> zzyj-outputvalcount-api-3.0.0-20220519.024924-14-sources.jar: com/ejianc/business/outputvalcount/vo/XmyxglVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目影像管理
 * 
 * @author generator
 * 
 */
public class XmyxglVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long xmId; // 项目id
    private String xmName; // 项目名称
    private Long sgdwId; // 施工单位id
    private String sgdwName; // 施工单位
    private String yxmc; // 影像名称
    private Integer gclx; // 工程类型(1线性工程，2群体工程、3单体工程、4其他)
    private Long ssxjzId; // 所属巡检组id
    private String ssxjzName; // 所属巡检组
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date psrq; // 拍摄日期
    private String pssm; // 拍摄说明
    private Integer syxs; // 是否显示在首页（1否，2是）


    public Integer getSyxs() {
        return syxs;
    }

    public void setSyxs(Integer syxs) {
        this.syxs = syxs;
    }
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @ReferSerialTransfer(referCode="project-set")
    public Long getXmId() {
        return xmId;
    }
    @ReferDeserialTransfer
    public void setXmId(Long xmId) {
        this.xmId = xmId;
    }
    public String getXmName() {
        return xmName;
    }

    public void setXmName(String xmName) {
        this.xmName = xmName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public String getYxmc() {
        return yxmc;
    }

    public void setYxmc(String yxmc) {
        this.yxmc = yxmc;
    }
    public Integer getGclx() {
        return gclx;
    }

    public void setGclx(Integer gclx) {
        this.gclx = gclx;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getPsrq() {
        return psrq;
    }

    public void setPsrq(Date psrq) {
        this.psrq = psrq;
    }
    public String getPssm() {
        return pssm;
    }

    public void setPssm(String pssm) {
        this.pssm = pssm;
    }

    
}

==> zzyj-outputvalcount-api-3.0.0-20230919.103817-254-sources.jar: com/ejianc/business/outputvalcount/vo/XmyxglVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目影像管理
 * 
 * @author generator
 * 
 */
public class XmyxglVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long xmId; // 项目id
    private String xmName; // 项目名称
    private Long sgdwId; // 施工单位id
    private String sgdwName; // 施工单位
    private String yxmc; // 影像名称
    private Integer gclx; // 工程类型(1线性工程，2群体工程、3单体工程、4其他)
    private Long ssxjzId; // 所属巡检组id
    private String ssxjzName; // 所属巡检组
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date psrq; // 拍摄日期
    private String pssm; // 拍摄说明
    private Integer syxs; // 是否显示在首页（1否，2是）
    private String truePath;//附件文件的真实路径
    private Long projectDepartmentId; // 项目组织id

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public Integer getSyxs() {
        return syxs;
    }

    public void setSyxs(Integer syxs) {
        this.syxs = syxs;
    }
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @ReferSerialTransfer(referCode="project-set")
    public Long getXmId() {
        return xmId;
    }
    @ReferDeserialTransfer
    public void setXmId(Long xmId) {
        this.xmId = xmId;
    }
    public String getXmName() {
        return xmName;
    }

    public void setXmName(String xmName) {
        this.xmName = xmName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public String getYxmc() {
        return yxmc;
    }

    public void setYxmc(String yxmc) {
        this.yxmc = yxmc;
    }
    public Integer getGclx() {
        return gclx;
    }

    public void setGclx(Integer gclx) {
        this.gclx = gclx;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getPsrq() {
        return psrq;
    }

    public void setPsrq(Date psrq) {
        this.psrq = psrq;
    }
    public String getPssm() {
        return pssm;
    }

    public void setPssm(String pssm) {
        this.pssm = pssm;
    }

    public String getTruePath() {
        return truePath;
    }

    public void setTruePath(String truePath) {
        this.truePath = truePath;
    }
}
